from FinNews.feed import Feed
from FinNews.sources import *

name = "FinNews"

__version__ = "1.0.2"

__all__ = ['Feed', 'Source', 'CNBC', 'SeekingAlpha', 'Investing', 'WSJ', 'Yahoo', 'FT', 'Fortune', 'MarketWatch', 'Zacks', 'Nasdaq', 'Reddit']
